@@ -21,12 +21,28 @@
 
 #include <QtCore/QObject>
 
+class QItemSelectionModel;
+class QStandardItemModel;
+class QSortFilterProxyModel;
+
+class KLinkItemSelectionModel;
+
 class KLinkItemSelectionModelTest : public QObject
 {
     Q_OBJECT
 
 private Q_SLOTS:
+    void init();
+    void cleanup();
     void testToggle();
+    void testMainSetCurrent();
+    void testSubSetCurrent();
+
+private:
+    QStandardItemModel *m_mainModel;
+    QItemSelectionModel *m_mainSelectionModel;
+    QSortFilterProxyModel *m_subModel;
+    KLinkItemSelectionModel *m_subSelectionModel;
 };
 
 #endif /* KLINKITEMSELECTIONMODELTEST_H */
